#!/bin/sh -x
#######################################################################
#
# File: multiscan.sh
# 
#######################################################################
# 
#                     M A I N   P R O C E S S I N G
# 
#######################################################################
# 
# Set up a signalling flag.

RED_FLAG=0

#
# Determine where this script lives and set the serverroot and the
# instanceroot variables.
#
instanceroot=$(dirname $(dirname $(dirname $0)))
serverroot=$(dirname $instanceroot)      

# source the function library
. $instanceroot/imta/bin/ScriptFunctions   

getReferenceId		          # Get a reference Id.

#
# Scan methods you wish to invoke. They may include
#       sophos_sweep, nai_uvscan, catch_phrase,
#       seasonal_scan, and suffix_scan
# These methods are defined in the ScriptFunctions library.
#
SCAN_METHODS="sophos_sweep nai_uvscan trend_vscan"

#
# Type of file extension/suffix to block
#
SUFFIX_LIST="foo bar bazz"

RECORD_DIR="$instanceroot/log/virus" # Make sure it exists!
RECORD_FILE="${RECORD_DIR}/${REFERENCE_ID}"
DIAGNOSTIC_MSG="Possible Malicious Email Content Detected"
ERROR_POINTER_URL="http://www.duhmayne.eju/email/screening.html"
                   
for method in $SCAN_METHODS
do
    $method
    #
    # See if the FLAG was changed after the converter was 'launch'ed
    #
    if [ $RED_FLAG -eq 1 ]
    then
        write_record       # Log the MIME information of this message part.
        archive_msgpart    # Create a tarball containing the offending part.
        substitute_part    # Replace affected part with a substitute note.
        #force_delete      # Delete the current message part.
        #force_bounce      # Bounce the entire message.
        #force_hold        # Mark the message as .HELD
        exit
    fi           
done

# Prep for a 'seasonal' scan.
STATS_DIR="$instanceroot/log/SEASONAL"      #Make sure it exists
STATS_FILE="${STATS_DIR}/hotfiles.list"     #Make sure it exists
VERBOTEN_FILE="${STATS_DIR}/verboten.files" #Make sure it exists
EXEMPT_FILE="${STATS_DIR}/exempt.files"     #Make sure it exists
RECORD_FILE="${STATS_DIR}/Seasonal-${REFERENCE_ID}"
DIAGNOSTIC_MSG="Example: Possible Abuse of Network Bandwidth Detected" 
ERROR_POINTER_URL="http://url/with/more/info.html"

seasonal_scan

#
# See if the FLAG was changed after the converter was 'launch'ed
#

if [ $RED_FLAG -eq 1 ]
then
    write_record       # Log the MIME information of this message part
    substitute_part    # Replace affected part with a substitute note.
    #force_delete      # Delete the current message part.
    #force_bounce      # Bounce the entire message.
    #force_hold        # Mark the message as .HELD
    exit
fi

#
# If we made it to this point then the message part is OK
# so we do a simple rename operation.
#                                         

mv $INPUT_FILE $OUTPUT_FILE   # Message part is OK

exit 0;
