#!/bin/sh
#######################################################################
#  Template of a bourne shell script that could be setup to run as a 
#  companion to the 'seasonal_scan' method.
# 
#  The 'seasonal_scan' method of the iMS conversion channel script 
#  writes data to a file called 'hotfiles.list' in the ${RECORD_DIR}
#  directory.
#
#  The 'hotfiles.list' is sorted by the sixt field (the checksum) and 
#  that output piped to 'uniq -c' to get the number of times each unique
#  checksum occurs. 
# 
#  The max_size and max_count are thresholds for sending a file to the 
#  VERBOTEN list.
#
#  The sys admin could schedule a cronjob that runs this script on a 
#  regular basis.
#
#######################################################################
#

MAX_SIZE=10      # max size in Mbytes before being flagged 
MAX_COUNT=30     # max frequency before being flagged

RECORD_DIR="/pmdf/log/SEASONAL" 
STATS_FILE="${RECORD_DIR}/hotfiles.list"

cd ${RECORD_DIR}

touch ${RECORD_DIR}/verboten.files

sort +4 ${STATS_FILE} | uniq -c -f 4 | sort -r | \
while read line
do
  set $line

  frequency=$1
  checksum="$6"
  size="`expr $4 / 1048576`"    # 1.0 Mb is 1,048,576 bytes.
  shift 

  SIZE_ERR="Size $size Mb is larger than Max Allowed ($MAX_SIZE Mb): $*" 
  FRQ_ERR="Count ${frequency} is higher than Max Allowed ($MAX_COUNT): $*"

  # Find out if we already have this checksum on the verboten list.

  grep $checksum ${RECORD_DIR}/verboten.files  >/dev/null
  RETURN_STATUS="$?"
  if [ $RETURN_STATUS -eq 1 ]
  then
      if [ "$size" -gt $MAX_SIZE ]
      then
           echo $SIZE_ERR >> ${RECORD_DIR}/verboten.files
      fi

      if [ "$frequency" -gt $MAX_COUNT ]
      then
          echo $FRQ_ERR >> ${RECORD_DIR}/verboten.files
      fi
  fi
done

#######################################################################
#
#  Notify by email.
#

cat >  RECORD.msg <<END_MARK
From: Seasonal Scanner <scanner@duhmayne.eju>
To: Email Administrator <email-admin@duhmayne.eju>
Subject: The verboten list as of `date` 

END_MARK

cat RECORD.msg  ${RECORD_DIR}/verboten.files | /usr/lib/sendmail -t 

rm -f RECORD.msg

exit 0;
